==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySelfSubjectReviewSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;
import io.fabric8.kubernetes.api.model.PodTemplateSpecFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSecurityPolicySelfSubjectReviewSpecFluent<A extends io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.PodTemplateSpec getTemplate();
  public io.fabric8.kubernetes.api.model.PodTemplateSpec buildTemplate();
  public A withTemplate(io.fabric8.kubernetes.api.model.PodTemplateSpec template);
  public java.lang.Boolean hasTemplate();
  public io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent.TemplateNested<A> withNewTemplate();
  public io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent.TemplateNested<A> withNewTemplateLike(io.fabric8.kubernetes.api.model.PodTemplateSpec item);
  public io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent.TemplateNested<A> editTemplate();
  public io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent.TemplateNested<A> editOrNewTemplate();
  public io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent.TemplateNested<A> editOrNewTemplateLike(io.fabric8.kubernetes.api.model.PodTemplateSpec item);
  public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.PodTemplateSpecFluent<io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent.TemplateNested<N>>{
    public N and();
    public N endTemplate();
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySelfSubjectReviewSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;
import io.fabric8.kubernetes.api.model.PodTemplateSpecFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSecurityPolicySelfSubjectReviewSpecFluent<A extends io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.PodTemplateSpec getTemplate();
  public io.fabric8.kubernetes.api.model.PodTemplateSpec buildTemplate();
  public A withTemplate(io.fabric8.kubernetes.api.model.PodTemplateSpec template);
  public java.lang.Boolean hasTemplate();
  public io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent.TemplateNested<A> withNewTemplate();
  public io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent.TemplateNested<A> withNewTemplateLike(io.fabric8.kubernetes.api.model.PodTemplateSpec item);
  public io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent.TemplateNested<A> editTemplate();
  public io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent.TemplateNested<A> editOrNewTemplate();
  public io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent.TemplateNested<A> editOrNewTemplateLike(io.fabric8.kubernetes.api.model.PodTemplateSpec item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.PodTemplateSpecFluent<io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewSpecFluent.TemplateNested<N>>{
    public N and();
    public N endTemplate();
    
  }
  
}
